@@ -1,10 +1,7 @@
 /* man.h: Defines and external function declarations for man.c.
-   $Id: man.h 5191 2013-02-23 00:11:18Z karl $
+   $Id: man.h 5337 2013-08-22 17:54:06Z karl $
 
-   This file is part of GNU Info, a program for reading online documentation
-   stored in Info format.
-
-   Copyright (C) 1993, 1997, 2004, 2007 Free Software Foundation, Inc.
+   Copyright 1993, 1997, 2004, 2007, 2013 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,7 +16,7 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-   Author: Brian J. Fox (bfox@ai.mit.edu) Sat May  6 16:19:13 1995. */
+   Originally written by Brian Fox. */
 
 #ifndef INFO_MAN_H
 #define INFO_MAN_H
