@@ -1,6 +1,6 @@
 # Text.pm: output tree as simple text.
 #
-# Copyright 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
+# Copyright 2010, 2011, 2012 Free Software Foundation, Inc.
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -286,31 +286,19 @@ my %underline_symbol = (
   4 => '.'
 );
 
-sub heading($$$;$$)
+sub heading($$$;$)
 {
   my $current = shift;
   my $text = shift;
   my $converter = shift;
   my $numbered = shift;
-  my $indent_length = shift;
 
-  # REMARK to get the numberig right in case of an indented text, the
-  # indentation should be given here.  But this should never happen as
-  # the only @-commands allowed in indented context are not number.
   $text = Texinfo::Common::numbered_heading($converter, $current, $text, 
                                             $numbered);
   return '' if ($text !~ /\S/);
   my $result = $text ."\n";
-  if (defined($indent_length)) {
-    if ($indent_length < 0) {
-      $indent_length = 0;
-    }
-    $result .= (' ' x $indent_length);
-  } else {
-    $indent_length = 0;
-  }
   $result .=($underline_symbol{$current->{'level'}} 
-     x (Texinfo::Convert::Unicode::string_width($text) - $indent_length))."\n";
+     x Texinfo::Convert::Unicode::string_width($text))."\n";
   return $result;
 }
 
@@ -520,11 +508,11 @@ sub _convert($;$)
       } elsif ($root->{'cmdname'} ne 'node') {
         $result = _convert($root->{'args'}->[0], $options);
         if ($Texinfo::Common::sectioning_commands{$root->{'cmdname'}}) {
-          $result = heading($root, $result, $options->{'converter'}, 
-                            $options->{'NUMBER_SECTIONS'});
+          $result = heading ($root, $result, $options->{'converter'}, 
+                             $options->{'NUMBER_SECTIONS'});
         } else {
         # we always want an end of line even if is was eaten by a command
-          chomp($result);
+          chomp ($result);
           $result .= "\n";
         }
       }
