@@ -792,39 +792,39 @@ itemx vtable
 
 $result_errors{'table'} = [
   {
-    'error_line' => ':11: warning: Entry for index `cp\' outside of any node
+    'error_line' => ':11: warning: entry for index `cp\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 11,
     'macro' => '',
-    'text' => 'Entry for index `cp\' outside of any node',
+    'text' => 'entry for index `cp\' outside of any node',
     'type' => 'warning'
   },
   {
-    'error_line' => ':13: warning: Entry for index `vr\' outside of any node
+    'error_line' => ':13: warning: entry for index `vr\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 13,
     'macro' => '',
-    'text' => 'Entry for index `vr\' outside of any node',
+    'text' => 'entry for index `vr\' outside of any node',
     'type' => 'warning'
   },
   {
-    'error_line' => ':15: warning: Entry for index `ky\' outside of any node
+    'error_line' => ':15: warning: entry for index `ky\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 15,
     'macro' => '',
-    'text' => 'Entry for index `ky\' outside of any node',
+    'text' => 'entry for index `ky\' outside of any node',
     'type' => 'warning'
   },
   {
-    'error_line' => ':16: warning: Entry for index `vr\' outside of any node
+    'error_line' => ':16: warning: entry for index `vr\' outside of any node
 ',
     'file_name' => '',
     'line_nr' => 16,
     'macro' => '',
-    'text' => 'Entry for index `vr\' outside of any node',
+    'text' => 'entry for index `vr\' outside of any node',
     'type' => 'warning'
   }
 ];
