@@ -382,6 +382,19 @@ $result_converted{'plaintext'}->{'uref_in_ref'} = '*note cross ref with uref ure
 (href://http/myhost.com/index3.html))(file)node.
 ';
 
+$result_converted_errors{'plaintext'}->{'uref_in_ref'} = [
+  {
+    'file_name' => '',
+    'error_line' => ':1: warning: @ref cross-reference name should not contain `:\'
+',
+    'text' => '@ref cross-reference name should not contain `:\'',
+    'type' => 'warning',
+    'macro' => '',
+    'line_nr' => 1
+  }
+];
+
+
 
 $result_converted{'html_text'}->{'uref_in_ref'} = '<p><a href="index3.html#node">title with uref2 <a href="href://http/myhost.com/index2.html">uref2</a></a> in <cite>printed manual with uref4 <a href="href://http/myhost.com/index4.html">uref4</a></cite>
 </p>';
