@@ -279,30 +279,30 @@ $result_texts{'setfilename'} = '
 
 $result_errors{'setfilename'} = [
   {
-    'error_line' => ':2: warning: Multiple @setfilename
+    'error_line' => ':2: warning: multiple @setfilename
 ',
     'file_name' => '',
     'line_nr' => 2,
     'macro' => '',
-    'text' => 'Multiple @setfilename',
+    'text' => 'multiple @setfilename',
     'type' => 'warning'
   },
   {
-    'error_line' => ':3: warning: Multiple @setfilename
+    'error_line' => ':3: warning: multiple @setfilename
 ',
     'file_name' => '',
     'line_nr' => 3,
     'macro' => '',
-    'text' => 'Multiple @setfilename',
+    'text' => 'multiple @setfilename',
     'type' => 'warning'
   },
   {
-    'error_line' => ':4: warning: Multiple @setfilename
+    'error_line' => ':4: warning: multiple @setfilename
 ',
     'file_name' => '',
     'line_nr' => 4,
     'macro' => '',
-    'text' => 'Multiple @setfilename',
+    'text' => 'multiple @setfilename',
     'type' => 'warning'
   },
   {
@@ -329,7 +329,7 @@ $result_converted{'docbook'}->{'setfilename'} = '
 ';
 
 
-$result_converted{'info'}->{'setfilename'} = 'This is file_comment, produced by tp version from .
+$result_converted{'info'}->{'setfilename'} = 'This is file_comment, produced from .
 
 
 
@@ -340,9 +340,9 @@ End Tag Table
 
 $result_converted_errors{'info'}->{'setfilename'} = [
   {
-    'error_line' => 'warning: Document without nodes.
+    'error_line' => 'warning: document without nodes
 ',
-    'text' => 'Document without nodes.',
+    'text' => 'document without nodes',
     'type' => 'warning'
   }
 ];
