@@ -124,12 +124,12 @@ $result_texts{'multitable_not_closed'} = '';
 
 $result_errors{'multitable_not_closed'} = [
   {
-    'error_line' => ':1: No matching `@end multitable\'
+    'error_line' => ':1: no matching `@end multitable\'
 ',
     'file_name' => '',
     'line_nr' => 1,
     'macro' => '',
-    'text' => 'No matching `@end multitable\'',
+    'text' => 'no matching `@end multitable\'',
     'type' => 'error'
   }
 ];
