@@ -141,7 +141,7 @@ $result_errors{'image_in_paragraph'} = [];
 
 
 
-$result_converted{'plaintext'}->{'image_in_paragraph'} = 'Para. [Text for image out of paragraph.].  After image.
+$result_converted{'plaintext'}->{'image_in_paragraph'} = 'Para. Text for image out of paragraph..  After image.
 ';
 
 
