@@ -699,7 +699,7 @@ Next: <a href="#first" accesskey="n" rel="next">first</a>, Up: <a href="dir.html
 <a name="first"></a>
 <div class="header">
 <p>
-Next: <a href="manual1.html#Top" accesskey="n" rel="next">(manual1)</a>, Previous: <a href="manual2.html#Top" accesskey="p" rel="previous">(manual2)</a>, Up: <a href="manual3.html#Top" accesskey="u" rel="up">(manual3)</a> &nbsp; </p>
+Next: <a href="manual1.html#Top" accesskey="n" rel="next">(manual1)</a>, Previous: <a href="manual2.html#Top" accesskey="p" rel="prev">(manual2)</a>, Up: <a href="manual3.html#Top" accesskey="u" rel="up">(manual3)</a> &nbsp; </p>
 </div>
 <h4 class="node-heading">first</h4>
 <hr>
