@@ -935,7 +935,7 @@ element: @node third node
 ';
 
 
-$result_converted{'info'}->{'nodes_after_top_before_section_nodes'} = 'This is , produced by tp version from .
+$result_converted{'info'}->{'nodes_after_top_before_section_nodes'} = 'This is , produced from .
 
 
 File: ,  Node: Top,  Next: second node,  Up: (dir)
@@ -960,9 +960,9 @@ File: ,  Node: third node,  Prev: second node,  Up: Top
 
 
 Tag Table:
-Node: Top41
-Node: second node145
-Node: third node229
+Node: Top27
+Node: second node131
+Node: third node215
 
 End Tag Table
 ';
@@ -978,7 +978,6 @@ $result_converted{'html'}->{'nodes_after_top_before_section_nodes'} = '<!DOCTYPE
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<meta name="Generator" content="tp">
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
@@ -1032,7 +1031,7 @@ Next: <a href="#second-node" accesskey="n" rel="next">second node</a>, Up: <a hr
 <a name="second-node"></a>
 <div class="header">
 <p>
-Next: <a href="#third-node" accesskey="n" rel="next">third node</a>, Previous: <a href="#Top" accesskey="p" rel="previous">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Next: <a href="#third-node" accesskey="n" rel="next">third node</a>, Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h4 class="node-heading">second node</h4>
 
@@ -1042,7 +1041,7 @@ Next: <a href="#third-node" accesskey="n" rel="next">third node</a>, Previous: <
 <a name="third-node"></a>
 <div class="header">
 <p>
-Previous: <a href="#second-node" accesskey="p" rel="previous">second node</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#second-node" accesskey="p" rel="prev">second node</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <a name="subsection"></a>
 <h4 class="subsection">1 subsection</h4>
@@ -1056,9 +1055,9 @@ Previous: <a href="#second-node" accesskey="p" rel="previous">second node</a>, U
 
 $result_converted_errors{'html'}->{'nodes_after_top_before_section_nodes'} = [
   {
-    'error_line' => 'warning: Must specify a title with a title command or @top
+    'error_line' => 'warning: must specify a title with a title command or @top
 ',
-    'text' => 'Must specify a title with a title command or @top',
+    'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
 ];
