@@ -568,19 +568,19 @@ $result_menus{'section_before_top'}{'menu_child'}{'menu_up'} = $result_menus{'se
 
 $result_errors{'section_before_top'} = [
   {
-    'error_line' => ':5: Lowering the section level of @top appearing after a lower element
+    'error_line' => ':5: warning: lowering the section level of @top appearing after a lower element
 ',
     'file_name' => '',
     'line_nr' => 5,
     'macro' => '',
-    'text' => 'Lowering the section level of @top appearing after a lower element',
-    'type' => 'error'
+    'text' => 'lowering the section level of @top appearing after a lower element',
+    'type' => 'warning'
   }
 ];
 
 
 
-$result_converted{'info'}->{'section_before_top'} = 'This is , produced by tp version from .
+$result_converted{'info'}->{'section_before_top'} = 'This is , produced from .
 
 
 File: ,  Node: section node,  Prev: Top,  Up: Top
@@ -600,8 +600,8 @@ top
 
 
 Tag Table:
-Node: section node41
-Node: Top115
+Node: section node27
+Node: Top101
 
 End Tag Table
 ';
@@ -617,7 +617,6 @@ $result_converted{'html'}->{'section_before_top'} = '<!DOCTYPE html PUBLIC "-//W
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<meta name="Generator" content="tp">
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
@@ -656,7 +655,7 @@ ul.no-bullet {list-style: none}
 <a name="section-node"></a>
 <div class="header">
 <p>
-Previous: <a href="#Top" accesskey="p" rel="previous">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <a name="section"></a>
 <h3 class="section">1 section</h3>
