@@ -837,7 +837,7 @@ Next: <a href="#Chap-first-here" accesskey="n" rel="next">Chap first  here</a>,
 <a name="Chap-first-here"></a>
 <div class="header">
 <p>
-Next: <a href="#Test-title" accesskey="n" rel="next">Test               title</a>, Previous: <a href="#Top" accesskey="p" rel="previous">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Next: <a href="#Test-title" accesskey="n" rel="next">Test               title</a>, Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h4 class="node-heading">Chap first  here</h4>
 
@@ -845,7 +845,7 @@ Next: <a href="#Test-title" accesskey="n" rel="next">Test               title</a
 <a name="Test-title"></a>
 <div class="header">
 <p>
-Next: <a href="#Last-with-spaces" accesskey="n" rel="next">Last with spaces</a>, Previous: <a href="#Chap-first-here" accesskey="p" rel="previous">Chap first  here</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Next: <a href="#Last-with-spaces" accesskey="n" rel="next">Last with spaces</a>, Previous: <a href="#Chap-first-here" accesskey="p" rel="prev">Chap first  here</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h4 class="node-heading">Test               title</h4>
 
@@ -853,7 +853,7 @@ Next: <a href="#Last-with-spaces" accesskey="n" rel="next">Last with spaces</a>,
 <a name="Last-with-spaces"></a>
 <div class="header">
 <p>
-Previous: <a href="#Test-title" accesskey="p" rel="previous">Test               title</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#Test-title" accesskey="p" rel="prev">Test               title</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h4 class="node-heading">Last with spaces</h4>
 <hr>
