@@ -162,7 +162,7 @@ $result_errors{'top_no_argument_and_node'} = [];
 
 
 
-$result_converted{'info'}->{'top_no_argument_and_node'} = 'This is , produced by tp version from .
+$result_converted{'info'}->{'top_no_argument_and_node'} = 'This is , produced from .
 
 
 File: ,  Node: start
@@ -170,16 +170,16 @@ File: ,  Node: start
 
 
 Tag Table:
-Node: start41
+Node: start27
 
 End Tag Table
 ';
 
 $result_converted_errors{'info'}->{'top_no_argument_and_node'} = [
   {
-    'error_line' => 'warning: Document without Top node.
+    'error_line' => 'warning: document without Top node
 ',
-    'text' => 'Document without Top node.',
+    'text' => 'document without Top node',
     'type' => 'warning'
   }
 ];
@@ -196,7 +196,6 @@ $result_converted{'html'}->{'top_no_argument_and_node'} = '<!DOCTYPE html PUBLIC
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<meta name="Generator" content="tp">
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <link href="#start" rel="start" title="start">
 <style type="text/css">
@@ -244,9 +243,9 @@ ul.no-bullet {list-style: none}
 
 $result_converted_errors{'html'}->{'top_no_argument_and_node'} = [
   {
-    'error_line' => 'warning: Must specify a title with a title command or @top
+    'error_line' => 'warning: must specify a title with a title command or @top
 ',
-    'text' => 'Must specify a title with a title command or @top',
+    'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
 ];
